package com.example.sms.service.impl;

import com.aliyuncs.DefaultAcsClient;
import com.aliyuncs.IAcsClient;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsRequest;
import com.aliyuncs.dysmsapi.model.v20170525.SendSmsResponse;
import com.aliyuncs.exceptions.ClientException;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.profile.DefaultProfile;
import com.aliyuncs.profile.IClientProfile;
import com.example.sms.common.DingdongCloudApis;
import com.example.sms.common.SmsConst;
import com.example.sms.common.SmsParams;
import com.example.sms.dao.SmsConfigMapper;
import com.example.sms.model.SmsConfig;
import com.example.sms.service.SmsService;
import net.onebean.component.aliyun.AliyunSmsSendResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.List;

@Service("smsService")
public class SmsServiceImpl implements SmsService {

    @Value("${aliyun.oss.accessKeyId}")
    private String accessKeyId;

    @Value("${aliyun.oss.secretAccessKey}")
    private String accessKeySecret;

    @Value("${dingdong.apikey}")
    private String apikey;

    @Autowired
    private SmsConfigMapper smsConfigMapper;

    @Override
    public String sendMessage(SmsParams smsParams) {
        String message = "";
        String code = smsParams.getCode();
        //获取短信相关信息
        SmsConfig smsConfigInfo = smsConfigMapper.getSmsConfigInfo(code);
        if (null == smsConfigInfo){
            return SmsConst.CODE_NOT_FOUND;
        }
        String type = smsConfigInfo.getType();
        //阿里云短信发送
        if (type.equals("1")){
            message = sendMessageForAliyun(smsConfigInfo,smsParams);
        }else if (type.equals("2")){
            message = sendMessageForDingDong(smsConfigInfo,smsParams);
        }
        return message;
    }

    //叮咚云发送短信
    private String sendMessageForDingDong(SmsConfig smsConfigInfo, SmsParams smsParams) {
        String content = smsConfigInfo.getContent();
        if (!StringUtils.isEmpty(content))
        {
            content = getSendMeaasge(content,smsParams.getParams());

        }
        String message = "";
        if (smsConfigInfo.getMessageType().equals("1")){
            message = DingdongCloudApis.sendYzm(apikey,smsParams.getTel(),content);
        }else if (smsConfigInfo.getMessageType().equals("2")){
            message = DingdongCloudApis.sendTz(apikey,smsParams.getTel(),content);
        }else if (smsConfigInfo.getMessageType().equals("3")){
            message = DingdongCloudApis.sendYx(apikey,smsParams.getTel(),content);
        }
        return message;
    }

    //阿里云发送短信
    private String sendMessageForAliyun(SmsConfig smsConfigInfo,SmsParams smsParams) {
        List<String> paramsList = smsParams.getParams();
        String sendMessage = getSendMeaasge(smsConfigInfo.getContent(),paramsList);
        AliyunSmsSendResult aliyunSmsSendResult = sendSms(smsConfigInfo.getSignature(),smsConfigInfo.getTemplate(),smsParams.getTel(), sendMessage);
        if("OK".equals(aliyunSmsSendResult.getCode())){
            return SmsConst.SUCCESS;
        }else{
            SmsConfig smsDingdongInfo = smsConfigMapper.getSmsConfigInfo(smsConfigInfo.getBackupCode());
            return sendMessageForDingDong(smsDingdongInfo,smsParams);
        }
    }

    //把模板和传过来的参数组成发送的内容
    private String getSendMeaasge(String content, List<String> paramsList) {
        for (int i = 0; i < paramsList.size(); i++){
            content = content.replace("#"+i,paramsList.get(i));
        }
        return content;
    }

    public AliyunSmsSendResult sendSms(String smsSignature, String smsTemplate, String phoneNumber, String templateParamJsonStr) {
        AliyunSmsSendResult aliyunSmsSendResult = new AliyunSmsSendResult();
        aliyunSmsSendResult.setFlag(false);

        try {
            System.setProperty("sun.net.client.defaultConnectTimeout", "10000");
            System.setProperty("sun.net.client.defaultReadTimeout", "10000");
            String product = "Dysmsapi";
            String domain = "dysmsapi.aliyuncs.com";
            IClientProfile profile = DefaultProfile.getProfile("cn-hangzhou", accessKeyId, accessKeySecret);
            DefaultProfile.addEndpoint("cn-hangzhou", "cn-hangzhou", "Dysmsapi", "dysmsapi.aliyuncs.com");
            IAcsClient acsClient = new DefaultAcsClient(profile);
            SendSmsRequest request = new SendSmsRequest();
            request.setMethod(MethodType.POST);
            request.setPhoneNumbers(phoneNumber);
            request.setSignName(smsSignature);
            request.setTemplateCode(smsTemplate);
            request.setTemplateParam(templateParamJsonStr);
            request.setOutId("yourOutId");
            SendSmsResponse sendSmsResponse = (SendSmsResponse)acsClient.getAcsResponse(request);
            if (sendSmsResponse.getCode() != null && sendSmsResponse.getCode().equals("OK")) {
                aliyunSmsSendResult.setFlag(true);
            }

            aliyunSmsSendResult.setMsg(sendSmsResponse.getMessage());
            aliyunSmsSendResult.setCode(sendSmsResponse.getCode());
        } catch (ClientException e) {
            aliyunSmsSendResult.setCode("fail");
            aliyunSmsSendResult.setMsg("程序出错");
        }
        return aliyunSmsSendResult;
    }
}
